Module: XKPassword
- Defined in:
- lib/xkpassword.rb,
lib/xkpassword/cli.rb,
lib/xkpassword/version.rb,
lib/xkpassword/config_file.rb
Defined Under Namespace
Classes: CLI, ConfigFile, Generator, Store, Words
Constant Summary collapse
- VERSION =
'0.6.0'
Class Method Summary collapse
-
.generate(options = nil) ⇒ Object
Generates a random password by intializing a ‘XKPassword::Generator` instance.
Class Method Details
.generate(options = nil) ⇒ Object
Generates a random password by intializing a ‘XKPassword::Generator` instance. This accepts argumennts identcal to the above class.
If you are to generate multiple passwords (batch process lets say), you might as well directly use the ‘XKPassword::Generator` class as it will be faster since it will only need to load the dictionary once.
Presets provide named defaults for common password styles, and any explicit options passed to this method override the selected preset.
33 34 35 36 |
# File 'lib/xkpassword.rb', line 33 def self.generate( = nil) generator = XKPassword::Generator.new generator.generate() end |